===============================================================
``psyclone.tests.psyir.frontend.fparser2_bound_intrinsic_test``
===============================================================

.. automodule:: psyclone.tests.psyir.frontend.fparser2_bound_intrinsic_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.fparser2_bound_intrinsic_test
